@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
 our $DATE = '2015-08-19'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -377,6 +377,39 @@ sub gen_perinci_cmdline_completer_script {
         $code = join "", @res;
     } # END GENERATE CODE
 
+    # pack the modules
+    my $packed_code;
+    {
+        require App::depak;
+        require File::Slurper;
+        require File::Temp;
+
+        my (undef, $tmp_unpacked_path) = File::Temp::tempfile();
+        my (undef, $tmp_packed_path)   = File::Temp::tempfile();
+
+        File::Slurper::write_text($tmp_unpacked_path, $code);
+
+        my $res = App::depak::depak(
+            # tmp, while lcpan still indexes old periscomp
+            exclude_module  => ['JSON', 'JSON::Backend::PP','JSON::Boolean',
+                               'Data::Clean::FromJSON',
+                               'YAML::Old'],
+            exclude_pattern => ['^YAML::Old::.+'],
+            include_module  => ['JSON::PP'],
+
+            include_prereq => [sort keys %used_modules],
+            input_file     => $tmp_unpacked_path,
+            output_file    => $tmp_packed_path,
+            overwrite      => 1,
+            trace_method   => 'none',
+            pack_method    => 'datapack',
+            stripper       => 1,
+        );
+        return $res unless $res->[0] == 200;
+
+        $packed_code = File::Slurper::read_text($tmp_packed_path);
+    }
+
     if ($output_file ne '-') {
         $log->trace("Outputing result to %s ...", $output_file);
         if ((-f $output_file) && !$args{overwrite}) {
@@ -385,7 +418,7 @@ sub gen_perinci_cmdline_completer_script {
         open my($fh), ">", $output_file
             or return [500, "Can't open '$output_file' for writing: $!"];
 
-        print $fh $code;
+        print $fh $packed_code;
         close $fh
             or return [500, "Can't write '$output_file': $!"];
 
@@ -396,11 +429,10 @@ sub gen_perinci_cmdline_completer_script {
         my $output_name = $output_file;
         $output_name =~ s!.+[\\/]!!;
 
-        $code = "";
+        $packed_code = "";
     }
 
-    [200, "OK", $code, {
-        'func.used_modules' => [sort keys %used_modules],
+    [200, "OK", $packed_code, {
     }];
 }
 
@@ -419,14 +451,14 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.01 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-08-19.
+This document describes version 0.02 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-08-19.
 
 =head1 FUNCTIONS
 
 
 =head2 gen_perinci_cmdline_completer_script(%args) -> [status, msg, result, meta]
 
-Generate Perinci::CmdLine completer script.
+{en_US Generate Perinci::CmdLine completer script}.
 
 Arguments ('*' denotes required arguments):
 
@@ -438,29 +470,29 @@ Arguments ('*' denotes required arguments):
 
 =item * B<exclude_package_functions_match> => I<re>
 
-Exclude package functions matching this pattern.
+{en_US Exclude package functions matching this pattern}.
 
 =item * B<get_subcommand_from_arg> => I<int> (default: 1)
 
 =item * B<include_package_functions_match> => I<re>
 
-Only include package functions matching this pattern.
+{en_US Only include package functions matching this pattern}.
 
 =item * B<interpreter_path> => I<str>
 
-What to put on shebang line.
+{en_US What to put on shebang line}.
 
 =item * B<load_module> => I<array[str]>
 
-Load extra modules.
+{en_US Load extra modules}.
 
 =item * B<output_file> => I<str> (default: "-")
 
-Path to output file.
+{en_US Path to output file}.
 
 =item * B<overwrite> => I<bool> (default: 0)
 
-Whether to overwrite output if previously exists.
+{en_US Whether to overwrite output if previously exists}.
 
 =item * B<per_arg_json> => I<bool>
 
@@ -468,14 +500,15 @@ Whether to overwrite output if previously exists.
 
 =item * B<program_name>* => I<str>
 
-Program name that is being completed.
+{en_US Program name that is being completed}.
 
 =item * B<skip_format> => I<bool>
 
 =item * B<subcommand> => I<array[str]>
 
-Subcommand name followed by colon and function URL.
+{en_US Subcommand name followed by colon and function URL}.
 
+{en_US 
 Optionally, it can be additionally followed by a summary, so:
 
  NAME:URL[:SUMMARY]
@@ -484,10 +517,13 @@ Example (on CLI):
 
  --subcommand "delete:/My/App/delete_item:Delete an item"
 
+}
+
 =item * B<subcommands_from_package_functions> => I<bool>
 
-Form subcommands from functions under package's URL.
+{en_US Form subcommands from functions under package's URL}.
 
+{en_US 
 This is an alternative to the C<subcommand> option. Instead of specifying each
 subcommand's name and URL, you can also specify that subcommand names are from
 functions under the package URL in C<url>. So for example if C<url> is C</My/App/>,
@@ -503,9 +539,11 @@ then the subcommands become:
  bar => /My/App/bar
  "baz-qux" => /My/App/baz_qux
 
+}
+
 =item * B<url>* => I<str>
 
-URL to function (or package, if you have subcommands).
+{en_US URL to function (or package, if you have subcommands)}.
 
 =back
 
